package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type CollectionBannerResp struct {
	Title             string `description:"标题"`
	IndexImg          string `description:"小程序封面图"`
	Path              string `description:"小程序路径"`
	IsShowSustainable bool   `description:"是否展示限免标签"`
}

type CollectionBannerListResp struct {
	ListA []*CollectionBannerResp
	ListB *CollectionBannerResp
}

type CollectionDetailResp struct {
	HttpUrl string `description:"跳转地址"`
}

type ApplyCollectionReq struct {
	Content string `description:"内容"`
}

// 精选看板申请表
type CygxApplyCollection struct {
	ApplyCollectionId int       `orm:"column(apply_collection_id);pk" description:"主键ID"`
	UserId            int       `description:"用户ID"`         // 用户ID
	Mobile            string    `description:"手机号"`          // 手机号
	Email             string    `description:"邮箱"`           // 邮箱
	CompanyId         int       `description:"公司ID"`         // 公司ID
	CompanyName       string    `description:"公司名称"`         // 公司名称
	RealName          string    `description:"用户实际名称"`       // 用户实际名称
	SellerName        string    `description:"所属销售"`         // 所属销售
	CreateTime        time.Time `description:"创建时间"`         // 创建时间
	ModifyTime        time.Time `description:"修改时间"`         // 修改时间
	RegisterPlatform  int       `description:"来源 1小程序，2：网页"` // 来源 1小程序，2：网页
	Content           string    `description:" 内容"`          // 内容
}

// 精选看板申请表
type CygxApplyCollectionResp struct {
	ApplyCollectionId int       `gorm:"column:"`
	UserId            int       `gorm:"column:"`                    // 用户ID
	Mobile            string    `gorm:"column:"`                    // 手机号
	Email             string    `gorm:"column:"`                    // 邮箱
	CompanyId         int       `gorm:"column:;default:0"`          // 公司ID
	CompanyName       string    `gorm:"column:"`                    // 公司名称
	RealName          string    `gorm:"column:"`                    // 用户实际名称
	SellerName        string    `gorm:"column:"`                    // 所属销售
	CreateTime        time.Time `gorm:"column:"`                    // 创建时间
	ModifyTime        time.Time `gorm:"column:"`                    // 修改时间
	RegisterPlatform  int       `gorm:"column:;default:1;NOT NULL"` // 来源 1小程序，2：网页
	Content           string    `gorm:"column:;NOT NULL"`           // 内容
}

// 添加信息
func AddCygxApplyCollection(item *CygxApplyCollection) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

// 通过ID获取详情
func GetCygxApplyCollectionDetail(applyCollectionId int) (item *CygxApplyCollectionResp, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_apply_collection  WHERE apply_collection_id=?  `
	err = o.Raw(sql, applyCollectionId).QueryRow(&item)
	return
}

type CygxApplyCollectionDetailResp struct {
	Detail *CygxApplyCollectionResp
}
